@@ -28,8 +28,11 @@
 #include "eog-image.h"
 #include "eog-util.h"
 #include "eog-thumb-view.h"
+
+#if HAVE_EXIF
 #include "eog-exif-details.h"
 #include "eog-exif-util.h"
+#endif
 
 #include <glib.h>
 #include <glib/gi18n.h>
@@ -109,6 +112,7 @@ pd_update_general_tab (EogPropertiesDialog *prop_dlg,
 		       EogImage            *image)
 {
 	gchar *bytes_str, *dir_str, *mime_str, *uri_str;
+	gchar *width_str, *height_str;
 	const gchar *type_str; 
 	gint width, height, bytes;
 
@@ -123,11 +127,18 @@ pd_update_general_tab (EogPropertiesDialog *prop_dlg,
 
 	eog_image_get_size (image, &width, &height);
 
-	gtk_label_set_text (GTK_LABEL (prop_dlg->priv->width_label), 
-			    g_strdup_printf ("%d pixels", width));
+	width_str = g_strdup_printf ("%d %s", width,
+				     ngettext ("pixel", "pixels", width));
+	height_str = g_strdup_printf ("%d %s", height,
+				      ngettext ("pixel", "pixels", height));
+
+	gtk_label_set_text (GTK_LABEL (prop_dlg->priv->width_label), width_str);
 
 	gtk_label_set_text (GTK_LABEL (prop_dlg->priv->height_label), 
-			    g_strdup_printf ("%d pixels", height));
+			    height_str);
+
+	g_free (height_str);
+	g_free (width_str);
 
 	mime_str = gnome_vfs_get_mime_type (uri_str);
 	type_str = gnome_vfs_mime_get_description (mime_str);
@@ -269,7 +280,7 @@ pd_update_metadata_tab (EogPropertiesDialog *prop_dlg,
 	gtk_label_set_text (GTK_LABEL (priv->exif_date_label),
 			    eog_exif_util_format_date (exif_value));
 
-	eog_exif_details_update (EOG_EXIF_DETAILS (prop_dlg->priv->exif_details), 
+	eog_exif_details_update (EOG_EXIF_DETAILS (priv->exif_details), 
 				 exif_data);
 
 	exif_data_unref(exif_data);
@@ -282,29 +293,29 @@ pd_update_metadata_tab (EogPropertiesDialog *prop_dlg,
 		eog_xmp_set_label (xmp_data, 
 				   NS_IPTC4XMP, 
 				   "Location", 
-				   prop_dlg->priv->xmp_location_label);
+				   priv->xmp_location_label);
 
 		eog_xmp_set_label (xmp_data, 
 				   NS_DC, 
 				   "description", 
-				   prop_dlg->priv->xmp_description_label);
+				   priv->xmp_description_label);
 
 		eog_xmp_set_label (xmp_data, 
 				   NS_DC, 
 				   "subject", 
-				   prop_dlg->priv->xmp_keywords_label);
+				   priv->xmp_keywords_label);
 
 		eog_xmp_set_label (xmp_data, 
 				   NS_DC, 
         	                   "creator", 
-				   prop_dlg->priv->xmp_creator_label);
+				   priv->xmp_creator_label);
 
 		eog_xmp_set_label (xmp_data, 
 				   NS_DC, 
 				   "rights", 
-				   prop_dlg->priv->xmp_rights_label);
+				   priv->xmp_rights_label);
 
-		eog_exif_details_xmp_update (EOG_EXIF_DETAILS (prop_dlg->priv->exif_details), xmp_data);
+		eog_exif_details_xmp_update (EOG_EXIF_DETAILS (priv->exif_details), xmp_data);
 
 		xmp_free (xmp_data);
 	}
